@@ -41,6 +41,9 @@ FAILEDOPERATION_LICENSENOQUOTA = 'FailedOperation.LicenseNoQuota'
 # 签署审核未通过，请先完成审核。
 FAILEDOPERATION_NOSIGNREVIEWPASS = 'FailedOperation.NoSignReviewPass'
 
+# 此合同流程不支持审批
+FAILEDOPERATION_NOTAVAILABLESIGNREVIEW = 'FailedOperation.NotAvailableSignReview'
+
 # 未找到集团子企业相关用户信息，请检查用户相关参数
 FAILEDOPERATION_NOTFOUNDSHADOWUSER = 'FailedOperation.NotFoundShadowUser'
 
@@ -458,6 +461,9 @@ OPERATIONDENIED_INVALIDAPPROVERAGE = 'OperationDenied.InvalidApproverAge'
 # 资源id超过使用上限限制，请联系客服了解规则，并在修改后重试。
 OPERATIONDENIED_MANYRESOURCEID = 'OperationDenied.ManyResourceId'
 
+# 没有API权限。
+OPERATIONDENIED_NOAPIAUTH = 'OperationDenied.NoApiAuth'
+
 # 无权限操作签署流程，请联系客服了解权限，并在修改后重试。
 OPERATIONDENIED_NOFLOWPERMISSION = 'OperationDenied.NoFlowPermission'
 
